==> mobile_pos-1.0.1.tar.gz: lib/src/views/terminal/view_terminal_transaction.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_selector.dart';
import 'package:mobile_pos/src/shared_widgets/custom_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button_loader.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/views/terminal/terminal_transaction_view.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';
import 'package:mobile_pos/src/views/terminal/widget/filter_transaction_sheet.dart';
import 'package:share_plus/share_plus.dart';

class ViewTerminalTransaction extends StatefulWidget {
  final TerminalModel model;

  const ViewTerminalTransaction({super.key, required this.model});

  @override
  State<ViewTerminalTransaction> createState() =>
      _ViewTerminalTransactionState();
}

class _ViewTerminalTransactionState extends State<ViewTerminalTransaction> {
  bool isBusy = true;
  int currentPage = 0;
  int? currentDisputeSelection;
  BankBoxTransactionModel? transactionsModel;
  String searchKey = "";
  @override
  void initState() {
    fetchTransaction();
    super.initState();
  }

  fetchTransaction() async {
    transactionsModel = await ApiRequests.getTerminalTransactions();
    if (!mounted) {
      return;
    }
    isBusy = false;
    setState(() {});
  }

  fetchTransactionByRange(DateTime startDate, DateTime endDate) async {
    isBusy = true;
    setState(() {});
    transactionsModel =
        await ApiRequests.getTransactionByRange(startDate, endDate);
    if (!mounted) {
      return;
    }
    isBusy = false;
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        showLogo: pluginConfig.showLabel,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(24),
              Row(
                children: [
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Spacer(),
                  GestureDetector(
                      onTap: () async {
                        var value = await showRavenPayBottomSheet(context,
                            child: const FilterTransactionSheet());

                        if (value == null) {
                          return;
                        }
                        searchKey = "";
                        if ((value).containsKey(FilterType.direction)) {
                          searchKey = value[FilterType.direction];
                        }

                        if ((value as Map).containsKey(FilterType.duration)) {
                          int days = 1;
                          if (value[FilterType.duration]
                              .toString()
                              .contains("30")) {
                            days = 30;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("14")) {
                            days = 14;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("Custom")) {
                            final dates = await showBankBoxDateRangePicker(
                                context,
                                primaryColor: pluginConfig.theme!.primaryColor,
                                maxDays: 90);
                            if (dates == null) {
                              return;
                            }
                            if (dates.length < 2) {
                              return;
                            }
                            fetchTransactionByRange(dates[0], dates[1]);
                            return;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("Custom")) {}
                          fetchTransactionByRange(
                              DateTime.now().subtract(Duration(days: days)),
                              DateTime.now());
                        }
                        setState(() {});
                      },
                      child:
                          const RoundedItemContainer(asset: "filter_icon.png"))
                ],
              ),
              const Gap(24),
              BankBoxSelector(
                  itemSelected: currentPage,
                  onChanged: (val) {
                    currentPage = val;
                    setState(() {});
                  },
                  items: const ["All Transaction", "Disputed Transaction"]),
              const Gap(8),
              if (isBusy) ...[
                Expanded(
                  child: Center(
                    child: RavenButtonLoader(
                      size: 24,
                      color: pluginConfig.theme!.primaryColor,
                    ),
                  ),
                )
              ] else ...[
                if (currentPage == 1) ...[
                  Wrap(
                    children: [
                      DisputeFilterItem(
                        value: null,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "All",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 1,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "Pending",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 3,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "In-Review",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 4,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "Resolve",
                        selecteItem: currentDisputeSelection,
                      ),
                    ],
                  ),
                  const Gap(8),
                ],
                Expanded(
                    child: TerminalTransactionView(
                        onSwapRefresh: () {
                          searchKey = "";
                          fetchTransaction();
                        },
                        transactions: currentPage == 1
                            ? (filterTransaction()
                                .where((element) =>
                                    currentDisputeSelection == null
                                        ? (element.disputeStatus == 1 ||
                                            element.disputeStatus == 3 ||
                                            element.disputeStatus == 4)
                                        : (element.disputeStatus ==
                                            currentDisputeSelection))
                                .toList())
                            : filterTransaction()))
              ]
            ],
          ),
        ));
  }

  filterTransaction() {
    return (transactionsModel?.transactions ?? [])
        .where((element) =>
            element.direction.toUpperCase().contains(searchKey.toUpperCase()) ||
            (searchKey.toUpperCase().contains("FAILED") &&
                element.direction.isEmpty))
        .toList();
  }
}

class DisputeFilterItem extends StatelessWidget {
  final String name;
  final int? value;
  final Function(int?) onSelected;

  final int? selecteItem;
  const DisputeFilterItem(
      {super.key,
      required this.name,
      this.value,
      required this.selecteItem,
      required this.onSelected});

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => onSelected(value),
      child: Container(
          margin: const EdgeInsets.only(right: 8, top: 12),
          decoration: BoxDecoration(
              color: selecteItem == value
                  ? pluginTheme.isLightTheme
                      ? pluginConfig.theme!.primaryColor.withOpacity(0.08)
                      : pluginConfig.theme!.primaryColor.withOpacity(0.2)
                  : pluginTheme.getFGColor,
              borderRadius: BorderRadius.circular(16)),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 6),
          child: Text(
            name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w400,
                color: selecteItem == value
                    ? pluginConfig.theme!.primaryColor
                    : pluginTheme.isLightTheme
                        ? Colors.black
                        : null),
          )),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final String value;
  const ItemWidget({super.key, required this.value, required this.name});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w500, fontSize: 12, letterSpacing: 0.3)),
        const Gap(4),
        Text(value,
            style: subtitle.copyWith(
                fontSize: 14, color: Colors.black, fontWeight: FontWeight.w800))
      ],
    );
  }
}

class CardWidget extends StatelessWidget {
  final TerminalModel model;
  const CardWidget({super.key, required this.model});

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(16),
      child: Container(
          width: double.infinity,
          decoration: BoxDecoration(
              image: DecorationImage(
                  image: AssetImage(loadAsset("terminal_info_card_bg.png"))),
              color: pluginConfig.theme!.primaryColor),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 14, vertical: 14),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text("CASH IN",
                        style: subtitle.copyWith(
                            color:
                                pluginConfig.theme!.onPrimary.withOpacity(0.8),
                            fontSize: 12)),
                    const Gap(4),
                    RavenPayMoneyWidget(
                      amount: model.cashIn.toString(),
                      fontSize: 20,
                      color: pluginConfig.theme!.onPrimary,
                    ),
                  ],
                ),
              ),
              if (model.accountNumber != null &&
                  model.accountNumber!.isNotEmpty) ...[
                const Gap(12),
                Container(
                    padding:
                        const EdgeInsets.symmetric(horizontal: 12, vertical: 9),
                    width: double.infinity,
                    decoration:
                        BoxDecoration(color: Colors.black.withOpacity(0.4)),
                    child: Row(
                      children: [
                        Image.asset(
                          loadAsset("wema_logo.png"),
                          height: 22,
                        ),
                        const Gap(12),
                        Expanded(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(
                                "${model.accountNumber} *  ${model.accountName}",
                                overflow: TextOverflow.ellipsis,
                                maxLines: 1,
                                style: subtitle.copyWith(
                                    fontWeight: FontWeight.w500,
                                    color: pluginConfig.theme!.onPrimary),
                              ),
                              const Gap(2),
                              Text(model.bank.toString(),
                                  style: subtitle.copyWith(
                                      color: pluginConfig.theme!.onPrimary
                                          .withOpacity(0.8),
                                      fontWeight: FontWeight.w400,
                                      fontSize: 10)),
                            ],
                          ),
                        ),
                        const Gap(24),
                        GestureDetector(
                          onTap: () {
                            Share.share(
                                "${model.accountName ?? ""} ${model.accountNumber ?? ""} ${model.bank ?? ""}");
                          },
                          child: Container(
                              height: 28,
                              width: 28,
                              padding: const EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                  shape: BoxShape.circle,
                                  color: Colors.black.withOpacity(0.2)),
                              child: Image.asset(loadAsset("share_icon.png"))),
                        )
                      ],
                    )),
              ]
            ],
          )),
    );
  }
}

==> mobile_pos-1.1.1.tar.gz: lib/src/views/terminal/view_terminal_transaction.dart <==
// ignore_for_file: use_build_context_synchronously

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:mobile_pos/src/helpers/global_variables.dart';
import 'package:mobile_pos/src/helpers/helper_functions.dart';
import 'package:mobile_pos/src/models/bankbox_transaction_model.dart';
import 'package:mobile_pos/src/models/terminal_model.dart';
import 'package:mobile_pos/src/network/api_requests.dart';
import 'package:mobile_pos/src/shared_widgets/bankbox_selector.dart';
import 'package:mobile_pos/src/shared_widgets/custom_dialog.dart';
import 'package:mobile_pos/src/shared_widgets/raven_money_text.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_bottomsheet.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_button_loader.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_close_button.dart';
import 'package:mobile_pos/src/shared_widgets/ravenpay_scaffold.dart';
import 'package:mobile_pos/src/views/terminal/terminal_transaction_view.dart';
import 'package:mobile_pos/src/styles/ravenpay_app_colors.dart';
import 'package:mobile_pos/src/styles/ravenpay_textstyles.dart';
import 'package:mobile_pos/src/views/terminal/view_info_screen.dart';
import 'package:mobile_pos/src/views/terminal/widget/filter_transaction_sheet.dart';
import 'package:share_plus/share_plus.dart';

class ViewTerminalTransaction extends StatefulWidget {
  final TerminalModel model;

  const ViewTerminalTransaction({super.key, required this.model});

  @override
  State<ViewTerminalTransaction> createState() =>
      _ViewTerminalTransactionState();
}

class _ViewTerminalTransactionState extends State<ViewTerminalTransaction> {
  bool isBusy = true;
  int currentPage = 0;
  int? currentDisputeSelection;
  BankBoxTransactionModel? transactionsModel;
  String searchKey = "";
  @override
  void initState() {
    fetchTransaction();
    super.initState();
  }

  fetchTransaction() async {
    transactionsModel = await ApiRequests.getTerminalTransactions();
    if (!mounted) {
      return;
    }
    isBusy = false;
    setState(() {});
  }

  fetchTransactionByRange(DateTime startDate, DateTime endDate) async {
    isBusy = true;
    setState(() {});
    transactionsModel =
        await ApiRequests.getTransactionByRange(startDate, endDate);
    if (!mounted) {
      return;
    }
    isBusy = false;
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return RavenPayScaffold(
        backgroundColor: pluginTheme.isLightTheme ? AppColors.lightGrey3 : null,
        showLogo: pluginConfig.showLabel,
        body: Padding(
          padding: EdgeInsets.symmetric(horizontal: kHorizontalScreenPadding),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              const Gap(24),
              Row(
                children: [
                  const RavenPayCloseButton(
                    text: "",
                    isArrow: true,
                  ),
                  const Spacer(),
                  GestureDetector(
                      onTap: () async {
                        var value = await showRavenPayBottomSheet(context,
                            child: const FilterTransactionSheet());

                        if (value == null) {
                          return;
                        }
                        searchKey = "";
                        if ((value).containsKey(FilterType.direction)) {
                          searchKey = value[FilterType.direction];
                        }

                        if ((value as Map).containsKey(FilterType.duration)) {
                          int days = 1;
                          if (value[FilterType.duration]
                              .toString()
                              .contains("30")) {
                            days = 30;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("14")) {
                            days = 14;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("Custom")) {
                            final dates = await showBankBoxDateRangePicker(
                                context,
                                primaryColor: pluginConfig.theme!.primaryColor,
                                maxDays: 90);
                            if (dates == null) {
                              return;
                            }
                            if (dates.length < 2) {
                              return;
                            }
                            fetchTransactionByRange(dates[0], dates[1]);
                            return;
                          }
                          if (value[FilterType.duration]
                              .toString()
                              .contains("Custom")) {}
                          fetchTransactionByRange(
                              DateTime.now().subtract(Duration(days: days)),
                              DateTime.now());
                        }
                        setState(() {});
                      },
                      child:
                          const RoundedItemContainer(asset: "filter_icon.png"))
                ],
              ),
              const Gap(24),
              BankBoxSelector(
                  itemSelected: currentPage,
                  onChanged: (val) {
                    currentPage = val;
                    setState(() {});
                  },
                  items: const ["All Transaction", "Disputed Transaction"]),
              const Gap(8),
              if (isBusy) ...[
                Expanded(
                  child: Center(
                    child: RavenButtonLoader(
                      size: 24,
                      color: pluginConfig.theme!.primaryColor,
                    ),
                  ),
                )
              ] else ...[
                if (currentPage == 1) ...[
                  Wrap(
                    children: [
                      DisputeFilterItem(
                        value: null,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "All",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 1,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "Pending",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 3,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "In-Review",
                        selecteItem: currentDisputeSelection,
                      ),
                      DisputeFilterItem(
                        value: 4,
                        onSelected: (val) {
                          currentDisputeSelection = val;
                          setState(() {});
                        },
                        name: "Resolve",
                        selecteItem: currentDisputeSelection,
                      ),
                    ],
                  ),
                  const Gap(8),
                ],
                Expanded(
                    child: TerminalTransactionView(
                        onSwapRefresh: () {
                          searchKey = "";
                          fetchTransaction();
                        },
                        transactions: currentPage == 1
                            ? (filterTransaction()
                                .where((element) =>
                                    currentDisputeSelection == null
                                        ? (element.disputeStatus == 1 ||
                                            element.disputeStatus == 3 ||
                                            element.disputeStatus == 4)
                                        : (element.disputeStatus ==
                                            currentDisputeSelection))
                                .toList())
                            : filterTransaction()))
              ]
            ],
          ),
        ));
  }

  filterTransaction() {
    return (transactionsModel?.transactions ?? [])
        .where((element) =>
            (element.direction ?? "")
                .toUpperCase()
                .contains(searchKey.toUpperCase()) ||
            (searchKey.toUpperCase().contains("FAILED") &&
                (element.direction ?? "").isEmpty))
        .toList();
  }
}

class DisputeFilterItem extends StatelessWidget {
  final String name;
  final int? value;
  final Function(int?) onSelected;

  final int? selecteItem;
  const DisputeFilterItem(
      {super.key,
      required this.name,
      this.value,
      required this.selecteItem,
      required this.onSelected});

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => onSelected(value),
      child: Container(
          margin: const EdgeInsets.only(right: 8, top: 12),
          decoration: BoxDecoration(
              color: selecteItem == value
                  ? pluginTheme.isLightTheme
                      ? pluginConfig.theme!.primaryColor.withOpacity(0.08)
                      : pluginConfig.theme!.primaryColor.withOpacity(0.2)
                  : pluginTheme.getFGColor,
              borderRadius: BorderRadius.circular(16)),
          padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 6),
          child: Text(
            name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w400,
                color: selecteItem == value
                    ? pluginConfig.theme!.primaryColor
                    : pluginTheme.isLightTheme
                        ? Colors.black
                        : null),
          )),
    );
  }
}

class ItemWidget extends StatelessWidget {
  final String name;
  final String value;
  const ItemWidget({super.key, required this.value, required this.name});

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Text(name,
            style: subtitle.copyWith(
                fontWeight: FontWeight.w500, fontSize: 12, letterSpacing: 0.3)),
        const Gap(4),
        Text(value,
            style: subtitle.copyWith(
                fontSize: 14, color: Colors.black, fontWeight: FontWeight.w800))
      ],
    );
  }
}

class CardWidget extends StatelessWidget {
  final TerminalModel model;
  const CardWidget({super.key, required this.model});

  @override
  Widget build(BuildContext context) {
    return ClipRRect(
      borderRadius: BorderRadius.circular(16),
      child: Container(
          width: double.infinity,
          decoration: BoxDecoration(
              image: DecorationImage(
                  image: AssetImage(loadAsset("terminal_info_card_bg.png"))),
              color: pluginConfig.theme!.primaryColor),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 14, vertical: 14),
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text("CASH IN",
                        style: subtitle.copyWith(
                            color:
                                pluginConfig.theme!.onPrimary.withOpacity(0.8),
                            fontSize: 12)),
                    const Gap(4),
                    RavenPayMoneyWidget(
                      amount: model.cashIn.toString(),
                      fontSize: 20,
                      color: pluginConfig.theme!.onPrimary,
                    ),
                  ],
                ),
              ),
              if (model.accountNumber != null &&
                  model.accountNumber!.isNotEmpty) ...[
                const Gap(12),
                Container(
                    padding:
                        const EdgeInsets.symmetric(horizontal: 12, vertical: 9),
                    width: double.infinity,
                    decoration:
                        BoxDecoration(color: Colors.black.withOpacity(0.4)),
                    child: Row(
                      children: [
                        Image.asset(
                          loadAsset("wema_logo.png"),
                          height: 22,
                        ),
                        const Gap(12),
                        Expanded(
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              Text(
                                "${model.accountNumber} *  ${model.accountName}",
                                overflow: TextOverflow.ellipsis,
                                maxLines: 1,
                                style: subtitle.copyWith(
                                    fontWeight: FontWeight.w500,
                                    color: pluginConfig.theme!.onPrimary),
                              ),
                              const Gap(2),
                              Text(model.bank.toString(),
                                  style: subtitle.copyWith(
                                      color: pluginConfig.theme!.onPrimary
                                          .withOpacity(0.8),
                                      fontWeight: FontWeight.w400,
                                      fontSize: 10)),
                            ],
                          ),
                        ),
                        const Gap(24),
                        GestureDetector(
                          onTap: () {
                            Share.share(
                                "${model.accountName ?? ""} ${model.accountNumber ?? ""} ${model.bank ?? ""}");
                          },
                          child: Container(
                              height: 28,
                              width: 28,
                              padding: const EdgeInsets.all(8),
                              decoration: BoxDecoration(
                                  shape: BoxShape.circle,
                                  color: Colors.black.withOpacity(0.2)),
                              child: Image.asset(loadAsset("share_icon.png"))),
                        )
                      ],
                    )),
              ]
            ],
          )),
    );
  }
}
